aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/Target/TargetLowering.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2008-10-17 16:47:46 +0000
committerChris Lattner <sabre@nondot.org>2008-10-17 16:47:46 +0000
commit6bdcda3d3e30003fb6cef1d4e2fd3a5d5b40d3fc (patch)
tree41b5912ce69512f42f4d6dc44331f27285c622cb /include/llvm/Target/TargetLowering.h
parent58f15c482a7129c78ca809792b46befa20ea337d (diff)
downloadexternal_llvm-6bdcda3d3e30003fb6cef1d4e2fd3a5d5b40d3fc.zip
external_llvm-6bdcda3d3e30003fb6cef1d4e2fd3a5d5b40d3fc.tar.gz
external_llvm-6bdcda3d3e30003fb6cef1d4e2fd3a5d5b40d3fc.tar.bz2
Keep track of *which* input constraint matches an output
constraint. Reject asms where an output has multiple input constraints tied to it. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@57687 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/Target/TargetLowering.h')
-rw-r--r--include/llvm/Target/TargetLowering.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/llvm/Target/TargetLowering.h b/include/llvm/Target/TargetLowering.h
index da4703c..5e5bdbe 100644
--- a/include/llvm/Target/TargetLowering.h
+++ b/include/llvm/Target/TargetLowering.h
@@ -1197,9 +1197,9 @@ public:
/// ConstraintVT - The ValueType for the operand value.
MVT ConstraintVT;
- /// isMatchingConstraint - Return true of this is an input operand that is a
- /// matching constraint like "4".
- bool isMatchingConstraint() const;
+ /// isMatchingInputConstraint - Return true of this is an input operand that
+ /// is a matching constraint like "4".
+ bool isMatchingInputConstraint() const;
/// getMatchedOperand - If this is an input matching constraint, this method
/// returns the output operand it matches.